@@ -15,7 +15,10 @@ fs.copySync('./package.json', './build/package.json');
 // Create the entry point file.
 var source = fs.readFileSync('index.js').toString();
 var template = Handlebars.compile(source);
-var data = { jupyterlab_extensions: package_data.jupyterlab.extensions };
+var data = {
+  jupyterlab_extensions: package_data.jupyterlab.extensions,
+  jupyterlab_mime_extensions: package_data.jupyterlab.mimeExtensions
+};
 var result = template(data);
 
 fs.writeFileSync(path.resolve(buildDir, 'index.out.js'), result);
